@@ -19,7 +19,7 @@ Boston, MA 02111-1307, USA.
 *-GNU-GPL-END-*/
 
 /*
-  $Id: ruli_search.c,v 1.7 2004/06/21 00:22:39 evertonm Exp $
+  $Id: ruli_search.c,v 1.8 2004/10/04 06:52:04 evertonm Exp $
  */
 
 
@@ -180,7 +180,7 @@ void ruli_search_srv_delete(ruli_search_srv_t *search)
   ruli_free(search);
 }
 
-int ruli_search_srv_code(ruli_search_srv_t *search)
+int ruli_search_srv_code(const ruli_search_srv_t *search)
 {
   assert(search);
   return search->srv_query.answer_code;
